@@ -30,16 +30,19 @@ setMethod("estimate", "CovControlMest", function(obj, x, ...)
 
 CovControlOgk <- function (niter=2, 
                            beta=0.90, 
-                           mrob=rrcov:::.mrobTau, 
-                           vrob=rrcov:::.vrobGK
+                           mrob=NULL, 
+                           vrob=rrcov:::.vrobGK,
+                           smrob="scaleTau2", 
+                           svrob="gk"
                            )
 {
-    new("CovControlOgk", niter=niter, beta=beta, mrob=mrob, vrob=vrob)        
+    new("CovControlOgk", niter=niter, beta=beta, mrob=mrob, vrob=vrob, smrob=smrob, svrob=svrob)
 }
 
 setMethod("estimate", "CovControlOgk", function(obj, x, ...) 
     CovOgk(x, control = obj, ...)
 )
+
 CovControlMve <- function (alpha=0.5,
                            nsamp=500,
                            seed=NULL,
@@ -56,13 +59,17 @@ setMethod("estimate", "CovControlMve", function(obj, x, ...)
 )
 
 CovControlSest <- function (bdp=0.5,
+                            arp=0.1,
+                            eps=1e-5,
+                            maxiter=120,
                             nsamp=500,
                             seed=NULL,
                             trace=FALSE,
                             tolSolve=10e-14,
-                            algo="sfast")
+                            method="sfast")
 {
-    new("CovControlSest", bdp=bdp, nsamp=nsamp, seed=seed, trace=trace, tolSolve=tolSolve, algo=algo)        
+    new("CovControlSest", bdp=bdp, arp=arp, eps=eps, maxiter=maxiter, 
+        nsamp=nsamp, seed=seed, trace=trace, tolSolve=tolSolve, method=method)        
 } 
 
 setMethod("estimate", "CovControlSest", function(obj, x, ...) 
